module V1
  
  class Auth < Grape::API

    helpers do
      include Apihelpers::ApiAuth
    end

    resource :auth do

      desc "Create a new user"
      params do
        requires :name, type: String, desc: "Name of user"
        requires :email, type: String, desc: "User's email"
        requires :password, type: String, desc: "User's password"
      end
      post :new do
        user = User.new
        if user.update_attributes(name: params[:name], email: params[:email], password: params[:password])
          {api_token: user.api_token}
        else
          {errors: user.errors.messages}
        end
      end

      desc "Creates and returns api_token if valid login"
      params do
        requires :email, type: String, desc: "Email address"
        requires :password, type: String, desc: "Password"
      end
      post :login do
        user = User.find_by_email(params[:email].downcase)
        if user && user.valid_password?(params[:password])
          user.generate_api_token
          user.save
          {api_token: user.api_token}
        else
          error!('Unauthorized.', 401)
        end
      end

      desc "logs out the user"
      params do
        requires :api_token, type: String, desc: "Api access token"
      end
      delete :logout do
        authenticated_user
        user = current_user
        user.invalidate_api_token
        user.save
        { message: "loged out"}
      end
    end


  end
end