module Shoppy
  class AccountsController < ApplicationController

    before_action :authenticate_admin!

    def customers
      @customers = Customer.all
    end

    def admins
      @admins = Admin.all
    end

    def newCustomer
      @customer                       = Customer.new
      @customer.name                  = params[:name]
      @customer.phone                 = params[:phone]
      @customer.password              = params[:password]
      @customer.password_confirmation = params[:password_confirmation]
      @customer.email                 = params[:email]
      @customer.gender                = params[:gender]
      if @customer.save
        Log.newEvent("Users", "Customer with email #{@customer.email} was created", current_admin.name)
        redirect_to '/accounts/customers'
        flash[:notice] = "User has been created."
      else
        ## TODO: Handle Errors
        redirect_to '/accounts/customers'
        flash[:error] = @customer.errors.messages
      end
    end

    def newAdmin
      @admin                          = Admin.new
      @admin.name                     = params[:name]
      @admin.phone                    = params[:phone]
      @admin.password                 = params[:password]
      @admin.password_confirmation    = params[:password_confirmation]
      @admin.email                    = params[:email]
      @admin.gender                   = params[:gender]
      if @admin.save
        Log.newEvent("Users", "Admin with email #{@admin.email} was created", current_admin.name)
        redirect_to '/accounts/admins'
        flash[:notice] = "Admin has been created."
      else
        ## TODO: Handle Errors
        redirect_to '/accounts/admins'
        flash[:error] = @admin.errors.messages
      end
    end

    def show
      user = User.find_by(id: params[:user_id])
      if user
        @user = user
      else
        page_not_found
      end
    end

    def edit
      @user = User.find_by(id: params[:user_id])
      if @user
        @user.update_attributes(@user.type == "Admin" ? admin_params : customer_params)
        Log.newEvent("Users", "Customer with email #{@user.email} was updated", current_admin.name)
        redirect_to '/accounts/' + params[:user_id]
        flash[:notice] = "User has been updated."
      end
    end

    def delete
      @user = User.find_by(id: params[:user_id])
      if @user
        r = @user.type.downcase + "s"
        if @user != current_admin
          @user.destroy
          Log.newEvent("Users",  "User #{@user.name} was deleted", current_admin.name)
          flash[:notice] = @user.type +  " has been deleted."
        else
          flash[:warning] = "You can't delete yourself, you punk 😡"
        end
        if params[:view] == "show"
          redirect_to '/accounts/#{@user.id}'
        else
          redirect_to '/accounts/' + r
        end
      else
        page_not_found
      end
    end

    private
    def customer_params
      params.require(:customer).permit(:name, :email, :phone, :gender)
    end

    def admin_params
      params.require(:admin).permit(:name, :email, :phone, :gender)
    end

  end
end