module Shoppy
  class BrandsController < ApplicationController
    before_action :authenticate_admin!

    def index
      @brands = Brand.all
      @brand = Brand.new
    end

    def new
      @brand = Brand.new(brand_params)
      @brand.name = @brand.name
      if @brand.save
        Log.newEvent("Brands", "New brand named '#{@brand.name}' was created", current_admin.name)
        flash[:notice] = "Brand has been created."
      else
        flash[:error] = @brand.errors.messages
      end
      redirect_to '/products/brands'
    end

    def show
      b = Brand.find_by(id: params[:brand_id])
      if b
        @brand = b
      else
        page_not_found
      end
    end

  def edit
      @brand = Brand.find_by(id: params[:brand_id])
      if @brand
        @brand.update_attributes(brand_params)
        Log.newEvent("Brands", "Brand named '#{@brand.name}' was updated", current_admin.name)
        redirect_to '/products/brands/' + @brand.id.to_s
        flash[:notice] = "Brand has been updated."
      else
        page_not_found
      end
    end

    def delete
      @brand = Brand.find_by(id: params[:brand_id])
      if @brand
        @brand.destroy
        Log.newEvent("Brands", "Brand named '#{@brand.name}' was deleted", current_admin.name)
        flash[:notice] = "Brand has been deleted."
        redirect_to '/products/brands'
      else
        page_not_found
      end
    end

    private
    def brand_params
      params.require(:brand).permit! # Permits all
    end
  end
end