module Shoppy
  class CategoriesController < ApplicationController
    before_action :authenticate_admin!

    include ERB::Util

    def index
      @categories = Category.all_sorted
    end

    def new
      @category = Category.new
      @category.name = params[:name]
      if params[:parent_category_id][:id].to_i != 0
        @category.parent_category = Category.find((params[:parent_category_id][:id]).to_i)
      end
      if @category.save
        Log.newEvent("Categories", "a new category named '#{@category.name}' was created", current_admin.name)
        flash[:notice] = "Category has been created."
      else
        ## TODO: Handle Errors
        flash[:error] = @category.errors.messages
      end
      redirect_to '/products/categories'
    end

    def show
      c = Category.find_by(id: params[:category_id])
      if c
        @category = c
      else
        page_not_found
      end
    end


    def edit
      @category = Category.find_by(id: params[:category_id])
      if @category
        if @category.update_attributes(category_params)
          Log.newEvent("Categories", "Category named '#{@category.name}' was updated", current_admin.name)
          flash[:notice] = "Category has been updated."
        else
          flash[:error] = @category.errors.messages
        end
        redirect_to '/products/categories/' + @category.id.to_s
      else
        page_not_found
      end
    end



    def delete
      @category = Category.find_by(id: params[:category_id])
      if @category
        @category.destroy
        Log.newEvent("Categories", "Category named '#{@category.name}' was deleted", current_admin.name)
        flash[:notice] = "Catgory has been deleted."
        redirect_to '/products/categories'
      else
        page_not_found
      end
    end

    private
    def category_params
      params.require(:category).permit(:name, :parent_category_id)
    end

  end
end