module Shoppy
  class CustomerAddressesController < ApplicationController
    before_action :authenticate_admin!

    def index
      @customer = Customer.find_by(id: params[:customer_id])
      if @customer
        @addresses = @customer.customer_addresses
        respond_to do |format|
          format.html # show.html.erb
          format.xml  { render :xml => @addresses.map { |address| address.as_json(:only => :id, :methods => [:name, :add_line1, :add_line2, :city, :state, :country, :zip, :customer_id]) } }
          format.json { render :json => @addresses.map { |address| address.as_json(:only => :id, :methods => [:name, :add_line1, :add_line2, :city, :state, :country, :zip, :customer_id]) } }
        end
      else
        redirect_to "404.html"
      end
    end

    def new
      @customer = Customer.find_by(id: params[:customer_id])
      if @customer
        @address = CustomerAddress.new
        @address.customer   = @customer
        @address.name     = params[:name]
        @address.add_line1  = params[:add_line1]
        @address.add_line2  = params[:add_line2]
        @address.city       = params[:city]
        @address.state      = params[:state]
        @address.country    = params[:country]
        @address.zip        = params[:zip]
        if @address.save
          Log.newEvent("Customr Addresses", "A new address for customer '#{@customer.name}' was created", current_admin.name)
          flash[:notice]    = "Address has been created successfully."
        else
          flash[:error]    = @address.errors.messages
        end
        redirect_to "/accounts/" + @customer.id.to_s + "/addresses"
      else
        page_not_found
      end
    end

    def show
      customer = Customer.find_by(id: params[:customer_id])
      address  = CustomerAddress.find_by(id: params[:address_id])
      if customer && address && address.customer == customer
        @customer = customer
        @address  = address
      else
        page_not_found
      end
    end

    def edit
      customer = Customer.find_by(id: params[:customer_id])
      address  = CustomerAddress.find_by(id: params[:address_id])
      if customer && address && address.customer == customer
        @customer = customer
        @address  = address
        if @address.update_attributes(address_params)
          Log.newEvent("Customr Addresses", "An address for customer '#{@customer.name}' was updated", current_admin.name)
          flash[:notice] = "Address updated successfully."
        else
          flash[:error] = @address.errors.messages
        end
        redirect_to "/accounts/" + @customer.id.to_s + "/addresses/" + address.id.to_s
      else
        page_not_found
      end
    end

    def delete
      customer = Customer.find_by(id: params[:customer_id])
      address  = CustomerAddress.find_by(id: params[:address_id])
      if customer && address && address.customer == customer
        address.destroy
        Log.newEvent("Customr Addresses", "An address for customer '#{@customer.name}' was deleted", current_admin.name)
        flash[:notice] = "Address has been deleted."
        redirect_to "/accounts/"+ @customer.id + "/addresses"
      else
        page_not_found
      end
    end

    private
    def address_params
      params.require(:customer_address).permit(:name, :add_line1, :add_line2, :city, :state, :country, :zip)
    end
  end
end