module Shoppy
  class LocationsController < ApplicationController
    before_action :authenticate_admin!

    def index
      @stock_locations = StockLocation.all.order("name ASC")
    end

    def new
      @stock_location = StockLocation.new
      @stock_location.name      = params[:name]
      @stock_location.phone     = params[:phone]
      @stock_location.email     = params[:email]
      @stock_location.add_line1 = params[:add_line1]
      @stock_location.add_line2 = params[:add_line2]
      @stock_location.city      = params[:city]
      @stock_location.state     = params[:state]
      @stock_location.zip       = params[:zip]
      if @stock_location.save
        Log.newEvent("Stock Locations", "A new stock Location named '#{@stock_location.name}' was created", current_admin.name)
        flash[:notice] = "Stock Location has been created."
      else
        ## TODO: Handle Errors
        flash[:error] = @stock_location.errors.messages
      end
      redirect_to '/locations'
    end


    def show
      sl = StockLocation.find_by(id: params[:location_id])
      if sl
        @stock_location = sl
      else
        page_not_found
      end
    end

    def edit
      @stock_location = StockLocation.find_by(id: params[:location_id])
      if @stock_location
        if @stock_location.update_attributes(stock_location_params)
          Log.newEvent("Stock Locations", "Stock Location named '#{@stock_location.name}' was updated", current_admin.name)
          flash[:notice] = "Stock Location has been updated."
        else
          flash[:error] = @stock_location.errors.messages
        end
        redirect_to '/locations/' + @stock_location.id.to_s
      else
        page_not_found
      end
    end

    def delete
      stock_location = StockLocation.find_by(id: params[:location_id])
      if stock_location
        if stock_location.check_inventory
            stock_location.destroy
            Log.newEvent("Stock Locations", "Stock Location named '#{stock_location.name}' was deleted", current_admin.name)
            flash[:notice] = "Stock Location has been deleted."
        else
          flash[:warning] = "You can't delete stock location that has inventory"
        end
        if params[:view] == "show"
          redirect_to '/locations/#{@location.id}'
        else
        redirect_to '/locations'
        end
      else
        page_not_found
      end
    end


    private
    def stock_location_params
      params.require(:stock_location).permit(:name, :email, :phone, :add_line1, :add_line2, :city, :state, :country, :zip)
    end
  end
end