module Shoppy
  class ManufacturersController < ApplicationController
    before_action :authenticate_admin!

    def index
      @manufacturers = Manufacturer.all
    end

    def new
      @manufacturer = Manufacturer.new
      @manufacturer.name      = params[:name]
      @manufacturer.phone     = params[:phone]
      @manufacturer.email     = params[:email]
      @manufacturer.website   = params[:website]
      @manufacturer.add_line1 = params[:add_line1]
      @manufacturer.add_line2 = params[:add_line2]
      @manufacturer.city      = params[:city]
      @manufacturer.state     = params[:state]
      @manufacturer.country   = params[:country]
      @manufacturer.zip       = params[:zip]
      if @manufacturer.save
        Log.newEvent("Manufacturers", "A new manufacturer named '#{@manufacturer.name}' was created", current_admin.name)
        flash[:notice] = "Manufacturer has been created."
      else
        ## TODO: Handle Errors
        flash[:error] = @manufacturer.errors.messages
      end
      redirect_to '/products/manufacturers'
    end

    def show
      c = Manufacturer.find_by(id: params[:manufacturer_id])
      if c
        @manufacturer = c
      else
        page_not_found
      end
    end


    def edit
      @manufacturer = Manufacturer.find_by(id: params[:manufacturer_id])
      if @manufacturer
        if @manufacturer.update_attributes(category_params)
          Log.newEvent("Manufacturers", "Manufacturer named '#{@manufacturer.name}' was updated", current_admin.name)
          flash[:notice] = "Manufacturer has been updated."
        else
          flash[:error] = @manufacturer.errors.messages
        end
        redirect_to '/products/manufacturers/' + @manufacturer.id.to_s
      else
        page_not_found
      end
    end



    def delete
      @manufacturer = Manufacturer.find_by(id: params[:manufacturer_id])
      if @manufacturer
        @manufacturer.destroy
        Log.newEvent("Manufacturers", "Manufacturer named '#{@manufacturer.name}' was deleted", current_admin.name)
        flash[:notice] = "Manufacturer has been deleted."
        redirect_to '/products/manufacturers'
      else
        page_not_found
      end
    end

    private
    def category_params
      params.require(:manufacturer).permit(:name, :email, :website, :phone, :add_line1, :add_line2, :city, :state, :zip)
    end

  end

end