module Shoppy
  class OrdersController < ApplicationController
    before_action :authenticate_admin!

    def index
      if params[:customer_id]
        @customer = Customer.find_by(id: params[:customer_id])
        if @customer
          @orders = Order.where(customer_id: params[:customer_id])
        else
          page_not_found
        end
      else
        @orders = Order.all
      end
    end

    def new
      customer = Customer.find_by(id: params[:order][:customer_id])
      address  = CustomerAddress.find_by(id: params[:address_id])
      if customer
        if address
          order_lines_hash = {}
          order_lines = params[:orderLines]
          order_lines.each do |oli, old|
            new_ols = { old["variant_id"] => old["quantity"].to_i }
            order_lines_hash = order_lines_hash.update(new_ols) { |k, v1, v2| v1 + v2 }
          end
          order = OrdersHelper::new_order(customer, order_lines_hash, address)
          if order
            flash[:notice] = "Order has been created for a total amount #{order.total_price}"
          else
            flash[:warning] = "Something wrong happend. please try again later"
          end
          redirect_to "/accounts/#{customer.id}/orders"
        else
          flash[:warning] = "You didn't select a customer"
          redirect_to "/orders"
        end
      else
        flash[:warning] = "Please select a Customer Address."
        redirect_to "/orders"
      end
    end

    def show
      r = Order.find_by(id: params[:order_id])
      if r
        @order = r
      else
        page_not_found
      end
    end

    def edit
      @order = Order.find_by(id: params[:order_id])
      (customer = Customer.find_by(id: params[:customer_id])) if params[:customer_id]
      if @order
        if params[:status] == "disapprove"
          if @order.status == "Approved"
            @order.status = "Cancelled"
            @order.save
            Log.newEvent("Orders",  "Order no. #{@order.id} for '#{@order.customer.name}' was cancelled", current_admin.name)
            flash[:notice] = "Order no. #{@order.id} for '#{@order.customer.name}' was cancelled"
          elsif @order.status == "Cancelled" || @order.status == "Pending"
            flash[:warning] = "Order is already not approved"
          elsif @order.status == "Processing" || @order.status == "Shipped"
            flash[:warning] = "Order is fully/partially shipped, so it can't be cancelled"
          else
            flash[:warning] = "Something went wrong. please try again later"
          end
        elsif params[:status] == "approve"
          if @order.status == "Cancelled" || @order.status == "Pending"
            @order.status = "Approved"
            @order.save
            Log.newEvent("Orders",  "Order no. #{@order.id} for '#{@order.customer.name}' was approved", current_admin.name)
            flash[:notice] = "Order no. #{@order.id} for '#{@order.customer.name}' was approved"
          else
            flash[:warning] = "Order is already approved"
          end
        else
          flash[:warning] = "Something went wrong. please try again later"
        end
        if params[:view] == "show"
          redirect_to "/orders/#{@order.id}"
        else
          if customer
            redirect_to "/accounts/#{customer.id}/orders"
          else
            redirect_to "/orders"
          end
        end
      else
        page_not_found
      end
    end

    def delete
      @order = Order.find_by(id: params[:order_id])
      (customer = Customer.find_by(id: params[:customer_id])) if params[:customer_id]
      if @order
        if @order.status == "Cancelled" || @order.status == "Pending"
          @order.destroy
          flash[:notice] = "Order no. #{@order.id} for '#{@order.customer.name}' was deleted"
          Log.newEvent("Orders",  "Order no. #{@order.id} for '#{@order.customer.name}' was deleted", current_admin.name)
        elsif @order.status == "Approved"
          flash[:warning] = "Order is currently approved, so it can't be deleted."
        elsif @order.status == "Shipped"
          flash[:warning] = "Order is currently shipped, so it can't be deleted."
        elsif @order.status == "Delivered"
          flash[:warning] = "Order is currently delivered, so it can't be deleted."
        else
          flash[:warning] = "Something wrong happend. Please try again later."
        end
        if params[:view] == "show"
          redirect_to '/accounts/#{@order.id}'
        else
          if customer
            redirect_to "/accounts/#{customer.id}/orders"
          else
            redirect_to "/orders"
          end
        end
      else
        page_not_found
      end
    end

  end
end