module Shoppy
  class ProductsController < ApplicationController
    before_action :authenticate_admin!

    def index
      @products = Product.all
      @options = []

      options = OptionsGroup.all.order("name ASC")
      options.each do |o|
        @options += [o.name]
      end
    end

    def new
      category       = Category.find(params[:category][:id]) if !params[:category][:id].empty?
      brand          = Brand.find(params[:brand][:id]) if !params[:brand][:id].empty?
      manufacturer   = Manufacturer.find(params[:manufacturer][:id]) if !params[:manufacturer][:id].empty?
      if brand && category && manufacturer
        Product.transaction do
          @product                = Product.new
          @product.name           = params[:name]
          @product.category       = Category.find(params[:category][:id]) if params[:category]
          @product.brand          = Brand.find(params[:brand][:id]) if params[:brand]
          @product.manufacturer   = Manufacturer.find(params[:manufacturer][:id]) if params[:manufacturer]
          if @product.save
            Log.newEvent("Products", "Product named '#{@product.name}' was created", current_admin.name)
            flash[:notice]  = "Product has been created successfully."
            options = ProductsHelper::convert_params_groups_to_objects(params[:options_groups][:ids])
            ProductsHelper::add_options_groups_to_product(@product, options)
          else
            flash[:error]   = @product.errors.messages
          end
        end
      else
        flash[:warning] = "Please select a Category, a Brand, and a Manufacturer for the product"
      end
      redirect_to "/products/items"
    end

    def show
      product = Product.find_by(id: params[:product_id])
      if product
        @product = product
      else
        page_not_found
      end
    end


    def edit
      product       = Product.find_by(id: params[:product_id])
      category      = Category.find(params[:category][:id]) if !params[:category][:id].empty?
      brand         = Brand.find(params[:brand][:id]) if !params[:brand][:id].empty?
      manufacturer  = Manufacturer.find(params[:manufacturer][:id]) if !params[:manufacturer][:id].empty?
        if product
          if category && brand && manufacturer
            Product.transaction do
              product.name           = params[:name]
              product.category       = category
              product.brand          = brand
              product.manufacturer   = manufacturer
              options = ProductsHelper::convert_params_groups_to_objects(params[:options_groups][:ids])
              ProductsHelper::update_options_groups_for_product(product, options)
              product.hash_data = {}
              hash = params[:hash]
              hash.each do |h_index, h_data|
                product.put_hash(h_data["k"], h_data["v"])
              end
              if product.save
                Log.newEvent("Products", "Product named '#{product.name}' was updated", current_admin.name)
                flash[:notice] = "product updated successfully"
              else
                flash[:warning] = "Something went wrong. Try again later"
              end
            end
          else
            flash[:warning] = "Please select a Category, a Brand, and a Manufacturer for the product"
          end
          redirect_to "/products/items/" + product.id.to_s
        else
          page_not_found
        end
    end

    def delete
      @product = Product.find_by(id: params[:product_id])
      if @product
        @product.destroy
        Log.newEvent("Products", "Product named '#{@product.name}' was updated", current_admin.name)
        flash[:notice] = "product has been deleted."
        redirect_to '/products/items'
      else
        page_not_found
      end
    end
  end
end