module Shoppy
  class ReviewsController < ApplicationController
    before_action :authenticate_admin!

    def index
      if params[:product_id]
        @product = Product.find_by(id: params[:product_id])
        if @product
          @reviews = Review.where(product_id: params[:product_id])
        else
          page_not_found
        end
      else
        @reviews = Review.all
      end
    end

    def show
      r = Review.find_by(id: params[:review_id])
      if r
        @review = r
      else
        page_not_found
      end
    end

    def edit
      review = Review.find_by(id: params[:review_id])
      (product = Product.find_by(id: params[:product_id])) if params[:product_id]
      if review
        if params[:status] == "approve"
          review.accepted = true
          review.save
          flash[:notice] = "Review has been approved."
          Log.newEvent("Review", "Review '#{review.id}' for product '#{review.product.name}' was approved", current_admin.name)
        elsif params[:status] == "disapprove"
          review.accepted = false
          review.save
          flash[:notice] = "Review has been disapproved."
          Log.newEvent("Review", "Review '#{review.id}' for product '#{review.product.name}' was disapproved", current_admin.name)
        else
          flash[:warning] = "Something went wrong. please try again"
        end
        if params[:view] = "show"
          redirect_to "/reviews/#{review.id}"
        else
          if product
            redirect_to "/products/items/#{product.id}/reviews"
          else
            redirect_to "/reviews"
          end
        end
      else
        page_not_found
      end
    end

    def delete
      review = Review.find_by(id: params[:review_id])
      if review
        review.destroy
        Log.newEvent("Review", "Review '#{review.id}' for product '#{review.product.name}' was deleted", current_admin.name)
        flash[:notice] = "review has been deleted."
        redirect_to '/reviews'
      else
        page_not_found
      end
    end
  end
end