module Shoppy
  class VariantsController < ApplicationController
    before_action :authenticate_admin!
    def index
      product = Product.find_by(id: params[:product_id])
      if product
        @product = product
        @variants = product.variants
      else
        page_not_found
      end
    end

    def new
      product = Product.find_by(id: params[:product_id])
      if product
        variant                             = Variant.new
        variant.product                     = product
        variant.name                        = params[:name]
        variant.reg_price                   = params[:reg_price]
        variant.promo_price                 = params[:promo_price]
        variant.promo_price_starts_on       = params[:promo_price_starts_on]
        variant.promo_price_ends_on         = params[:promo_price_ends_on]
        variant.points                      = params[:points]
        if params[:options]
          params[:options].each do |pok, poi|
            variant.put_option(pok, OptionsItem.find(poi.to_i).name)
          end
        end
        if variant.save
          Log.newEvent("Variant", "Variant named '#{variant.name}' for product '#{product.name}' was created", current_admin.name)
          flash[:notice] = "Variant Added successfully"
        else
          flash[:error] = variant.errors.messages
        end
        redirect_to "/products/items/#{product.id}/variants"
      else
        page_not_found
      end
    end

    def show
      product = Product.find_by(id: params[:product_id])
      variant = Variant.find_by(id: params[:variant_id])
      if product && variant && (variant.product == product)
        @variant = variant
      else
        page_not_found
      end
    end

    def edit
      product = Product.find_by(id: params[:product_id])
      variant = Variant.find_by(id: params[:variant_id])
      if product && variant && (variant.product == product)
        variant.name                            = params[:name]
        variant.reg_price                       = params[:reg_price]
        variant.promo_price                     = params[:promo_price]
        variant.promo_price_starts_on           = params[:promo_price_starts_on]
        variant.promo_price_ends_on             = params[:promo_price_ends_on]
        variant.points                          = params[:points]
        if params[:options]
          params[:options].each do |pok, poi|
            variant.put_option(pok, OptionsItem.find(poi.to_i).name)
          end
        end
        variant.hash_data = {}
        hash = params[:hash]
        hash.each do |h_index, h_data|
          variant.put_hash(h_data["k"], h_data["v"])
        end
        if variant.save
          Log.newEvent("Variant", "Variant named '#{variant.name}' for product '#{product.name}' was updated", current_admin.name)
          flash[:notice] = "Variant updated successfully"
        else
          flash[:error] = variant.errors.messages
        end
        redirect_to "/products/items/#{product.id}/variants/#{variant.id}"
      else
        page_not_found
      end
    end

    def delete
      product = Product.find_by(id: params[:product_id])
      variant = Variant.find_by(id: params[:variant_id])
      if product && variant && (variant.product == product)
        if variant.destroy
          Log.newEvent("Variant", "Variant named '#{variant.name}' for product '#{product.name}' was deleted", current_admin.name)
          flash[:notice] = "Variant deleted successfully."
        else
          flash[:warning] = "Something went wrong. please try again later."
        end
        if params[:viw] == "show"
          redirect_to "/products/items/#{product.id}/variants#{variant.id}"
        else
          redirect_to "/products/items/#{product.id}/variants"
        end
      else
        page_not_found
      end
    end
  end
end