module Shoppy
  class Category < ActiveRecord::Base
    ## Relationships
    belongs_to  :parent_category, class_name: "Category"
    has_many    :child_categories, class_name: "Category", foreign_key: "parent_category_id", dependent: :nullify
    has_many    :products, dependent: :nullify

    ## Filters
    before_save :caps

    ## Validators
    validates :name, presence: true
    validates :name, length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }
    validates :name, uniqueness: true
    validate  :parent_is_not_same_category


    def breadcrumb
      bc = [self.id]
      fbc = "Root -> "
      c = self
      while c.parent_category
        bc.append(c.parent_category.id)
        c = c.parent_category
      end
      bc.reverse.each do |c|
        fbc += (Category.find(c).name + " -> ")
      end
      fbc[0..(fbc.length - 5)]
    end

    def self.all_sorted
      self.all.sort_by {|c| c.breadcrumb }
    end




    private
    def parent_is_not_same_category
      if (self.parent_category_id != nil) && (self.parent_category_id == self.id)
        errors.add(:parent_category, "is same as selected category.")
      end
    end
    def caps
      self.name = self.name.downcase.titleize
    end

  end
end