module Shoppy::Concerns::Models::ApiTokenAuthenticatable
  extend ActiveSupport::Concern

  # For every model that you want to make ApiTokenAuthenticatable,
  # Add the following attributes to the model:
    # string    :api_token, null: false, default: ""
    # datetime  :api_token_expires_at
    # boolean   :api_token_active, null: false, default: false


  def api_token_expired?
    DateTime.now >= self.api_token_expires_at
  end

  def valid_api_token?
    self.api_token_active && !self.api_token_expired?
  end


  def generate_api_token
    begin
      self.api_token = SecureRandom.hex
    end while self.class.exists?(api_token: api_token)
    self.api_token_expires_at = DateTime.now + 1.day
    self.api_token_active = true
    self
  end

  def invalidate_api_token
    self.api_token = ""
    self.api_token_expires_at = Time.now
    self.api_token_active = false
  end


end