module Shoppy::Concerns::Models::Hashable
  extend ActiveSupport::Concern

  ## For each model that you need to make 'Hashable', make sure
  ## You have an attribute called 'hash_data' for that model.
  ## Also, make sure to give that attribute a default value in
  ## the database that is equal to an empty hash, or '{}'
  ##
  ## In simple format, add this field to your migration file:
  ## # Hashable
  ## t.hstore :hash_data, null: false, default: {}


  # This method will add a key value paid to the model
  # or update the value of the key, if the key is found
  # for a given instance of the model
  def put_hash(key, value)
    if self.hash_data[key] == nil
      self.hash_data.merge!({key => value}) unless key == ""
      self.hash_data_will_change! unless key == ""
      self
    else
      self.hash_data[key] = value unless key == ""
      self.hash_data_will_change! unless key == ""
      self
    end
  end

  # This mothos will delete the key/value pair for the
  # give instance, if the key is founf. if not, the command
  # will be ignored.
  def delete_hash(key)
    self.hash_data.delete(key)
    self.hash_data_will_change!
    self
  end

  def empty_hash
    self.hash_data = {}
    self.hash_data_will_change!
    self
  end


  ## These are shared mothods, a.k.a class methods
  module ClassMethods
    # Query all model instances that have a given key,
    # regardless of the valiue for that key.
    def by_hash_key(key)
      self.where("hash_data ? :key", key: key)
    end

    # Query all model instance sthat have a given
    # key/value pair.
    def by_hash_key_value(key, value)
      kv = key + "=>" + value
      self.where("hash_data @> :kv", kv: kv)
    end
  end
end