module Shoppy::Concerns::Models::Optionable
  extend ActiveSupport::Concern

  ## For each model that you need to make 'Optionable', make sure
  ## You have an attribute called 'options' for that model.
  ## Also, make sure to give that attribute a default value in
  ## the database that is equal to an empty option, or '{}'
  ##
  ## In simple format, add this field to your migration file:
  ## # Optionable
  ## t.hstore :options, null: false, default: {}


  # This method will add a key value paid to the model
  # or update the value of the key, if the key is found
  # for a given instance of the model
  def put_option(key, value)
    if self.options[key] == nil
      self.options.merge!({key => value}) unless key == ""
      self.options_will_change! unless key == ""
      self
    else
      self.options[key] = value unless key == ""
      self.options_will_change! unless key == ""
      self
    end
  end

  # This mothos will delete the key/value pair for the
  # give instance, if the key is founf. if not, the command
  # will be ignored.
  def delete_option(key)
    self.options.delete(key)
    self.options_will_change!
    self
  end

  def empty_option
    self.options = {}
    self.options_will_change!
    self
  end


  ## These are shared mothods, a.k.a class methods
  module ClassMethods
    # Query all model instances that have a given key,
    # regardless of the valiue for that key.
    def by_option_key(key)
      self.where("options ? :key", key: key)
    end

    # Query all model instance sthat have a given
    # key/value pair.
    def by_option_key_value(key, value)
      kv = key + "=>" + value
      self.where("options @> :kv", kv: kv)
    end
  end
end