module Shoppy
  class CustomerAddress < ActiveRecord::Base
    ## Relationships
    belongs_to :customer

    ## Filters
    before_save :caps

    ## Validators
    validates :name,            presence: true
    validates :add_line1,       presence: true
    validates :city,            presence: true
    validates :state,           presence: true
    validates :country,         presence: true

    validates :name,      length: { in: 2..50,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: false
    validates :add_line1, length: { in: 2..75,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: false
    validates :add_line2, length: { in: 2..75,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :city,      length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :state,     length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :country,   length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :zip,       length: { in: 5..6,   too_short: "must be at least 5 digits",            too_long: "must be exactly 5 digits"},            allow_blank: true

    validate :fail_same_name_for_customer


    private
    def fail_same_name_for_customer
      if CustomerAddress.find_by(customer_id: self.customer_id, name: self.name.downcase.titleize)
        errors.add(:name, "Customer has another addresses with the same name") unless self.name_was.downcase.titleize == self.name.downcase.titleize
      end
    end
    def caps
      self.name = self.name.downcase.titleize
      self.add_line1 = self.add_line1.downcase.titleize
      self.add_line2 = self.add_line2.downcase.titleize
      self.city = self.city.downcase.titleize
      self.state = self.state.upcase
      self.country = self.country.upcase
    end


  end
end