module Shoppy
  class Manufacturer < ActiveRecord::Base
    ## Relationships
    has_many :products, dependent: :nullify

    ## filters
    before_save :caps


    ## Validators
    validates :name,      presence: true
    validates :name,      uniqueness: true
    validates :name,      length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }
    validates :email,     length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :phone,     length: { in: 2..20,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :website,   length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :add_line1, length: { in: 2..75,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :add_line2, length: { in: 2..75,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :city,      length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :state,     length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :country,   length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :zip,       length: { is: 5,      too_short: "must be exactly 5 digits",            too_long: "must be exactly 5 digits"},            allow_blank: true

    private
    def caps
      self.name = self.name.downcase.titleize
      self.add_line1 = self.add_line1.downcase.titleize
      self.add_line2 = self.add_line2.downcase.titleize
      self.city = self.city.downcase.titleize
      self.state = self.state.upcase
      self.country = self.country.upcase
    end

  end
end