module Shoppy
  class OptionsGroup < ActiveRecord::Base
    ## Relationships
    has_many :options_items, dependent: :destroy
    has_and_belongs_to_many :products


    ## Validators
    validates :name,      presence: true
    validates :name,      uniqueness: true
    validates :display,   presence: true
    validates :name,      length: { in: 2..50, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }


    ## Filters
    before_destroy  :remove_from_variants
    before_save     :update_options_items
    before_save     :caps


    ## temp. Attrinbutes
    attr_accessor :items_string


    def optionsItems
      return OptionsHelper::items_to_string(self)
    end

    def optionsItems=(options_items)
      @items_string = options_items
    end


    private
    def remove_from_variants
      self.products.each do |p|
        p.variants.each do |v|
          v.delete_hash(self.name)
          v.save
        end
      end
    end
    def update_options_items
      if optionsItems != ""
        if self.new_record? == false
          OptionsHelper::update_options_items(self)
        end
      else
        errors.add(:optionsItems, "is blank!")
      end
    end
    def caps
      self.name = self.name.downcase.titleize
    end

  end
end