module Shoppy
  class Product < ActiveRecord::Base
    ## Relationships
    belongs_to  :brand
    belongs_to  :manufacturer
    belongs_to  :category
    has_many    :variants, dependent: :destroy
    has_many    :reviews
    has_and_belongs_to_many :options_groups

    ## Concerns
    include Shoppy::Concerns::Models::Hashable
    # include Promotional
    # include Taggable

    ## Validators
    validates :name, presence: true
    validates :name, length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }
    validates :name, uniqueness: true


    before_save :fail_no_belongs
    before_save :caps


    private
    def fail_no_belongs
      if self.category_id == nil
        errors.add(:category, "is blank!")
      end
      if self.brand_id == nil
        errors.add(:brand, "is blank!")
      end
      if self.manufacturer_id == nil
        errors.add(:manufacturer, "is blank!")
      end
    end
    def caps
      self.name = self.name.downcase.titleize
    end

  end
end