module Shoppy
  class User < ActiveRecord::Base
    # Include default devise modules. Others available are:
    # :confirmable, :lockable, :timeoutable and :omniauthable
    devise :database_authenticatable,
      :registerable,
      :recoverable,
      :rememberable,
      :trackable,
      :validatable


    ## STI
    self.inheritance_column = :type

    ## Concerns
    include Shoppy::Concerns::Models::ApiTokenAuthenticatable

    ## Filters
    before_create :generate_api_token
    before_save   :caps

    ## Validators
    validates :name,      presence: true
    validates :name,      length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }
    validates :phone,     length: { in: 2..25,  too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }, allow_blank: true
    validates :gender,    inclusion: {:in => ["Male", "Female", ""], message: "Must be 'Male', 'Female' or ''"}



    private
    def caps
      self.name = self.name.downcase.titleize
    end

  end
end