module Shoppy
  class Variant < ActiveRecord::Base
    ## Relationships
    belongs_to :product
    has_many :inventories, dependent: :destroy
    has_many :stock_locations, :through => :inventories
    has_many :cart_items, dependent: :destroy
    has_many :order_lines, dependent: :nullify

    ## Concerns
    include Shoppy::Concerns::Models::Hashable
    include Shoppy::Concerns::Models::Optionable
    include Shoppy::Concerns::Models::Promotional

    ## Filters
    before_create :update_options_groups
    before_save   :caps

    ## Validators
    validates :name, presence: true
    validates :name, length: { in: 2..100, too_short: "must have at least %{count} letters", too_long: "must have at most %{count} letters" }
    validates :name, uniqueness: true


    def variant_details
      "#{self.name} - #{self.price}"
    end

    private
    def update_options_groups
      if self.product == nil
        errors.add(:product, "is blank!")
        return false
      else
        if self.options.count == 0
          ogs = self.product.options_groups
          ogs.each do |og|
            self.put_option(og.name, "")
          end
        end
      end
    end
    def caps
      self.name = self.name.downcase.titleize
    end

  end
end