Rails.application.routes.draw do
  devise_for :admins

  constraints subdomain: "api" do
    mount Base      => '/'
  end

  root to: "home#index"

  ## Accounts' routes.
  get     '/accounts/admins'                                     => 'accounts#admins'
  post    '/accounts/admins'                                     => 'accounts#newAdmin'
  get     '/accounts/customers'                                  => 'accounts#customers'
  post    '/accounts/customers'                                  => 'accounts#newCustomer'
  get     '/accounts/:user_id'                                   => 'accounts#show'
  put     '/accounts/:user_id'                                   => 'accounts#edit'
  delete  '/accounts/:user_id'                                   => 'accounts#delete'

  ## Customers' Addresses
  get     '/accounts/:customer_id/addresses'                     => 'customer_addresses#index'
  post    '/accounts/:customer_id/addresses'                     => 'customer_addresses#new'
  get     '/accounts/:customer_id/addresses/:address_id'         => 'customer_addresses#show'
  put     '/accounts/:customer_id/addresses/:address_id'         => 'customer_addresses#edit'
  delete  '/accounts/:customer_id/addresses/:address_id'         => 'customer_addresses#delete'

  ## Customer' Cart
  get     '/accounts/:customer_id/cart'                          => 'cart#index'
  delete  '/accounts/:customer_id/cart'                          => 'cart#empty'
  delete  '/accounts/:customer_id/cart/:cart_item_id'            => 'cart#delete'

  ## stock locations' routes
  get     '/locations'                                           => 'locations#index'
  post    '/locations'                                           => 'locations#new'
  get     '/locations/:location_id'                              => 'locations#show'
  put     '/locations/:location_id'                              => 'locations#edit'
  delete  '/locations/:location_id'                              => 'locations#delete'

  # Inventories routes
  get     '/locations/:location_id/inventories'                  => 'inventories#index'
  post    '/locations/:location_id/inventories'                  => 'inventories#new'
  put     '/locations/:location_id/transfer'                     => 'inventories#transfer'

  # Brands' routes
  get     '/products/brands'                                     => 'brands#index'
  post    '/products/brands'                                     => 'brands#new'
  get     '/products/brands/:brand_id'                           => 'brands#show'
  put     '/products/brands/:brand_id'                           => 'brands#edit'
  delete  '/products/brands/:brand_id'                           => 'brands#delete'

  ## Categories' routes
  get     '/products/categories'                                 => 'categories#index'
  post    '/products/categories'                                 => 'categories#new'
  get     '/products/categories/:category_id'                    => 'categories#show'
  put     '/products/categories/:category_id'                    => 'categories#edit'
  delete  '/products/categories/:category_id'                    => 'categories#delete'

  ## Manufacturers' routes
  get     '/products/manufacturers'                              => 'manufacturers#index'
  post    '/products/manufacturers'                              => 'manufacturers#new'
  get     '/products/manufacturers/:manufacturer_id'             => 'manufacturers#show'
  put     '/products/manufacturers/:manufacturer_id'             => 'manufacturers#edit'
  delete  '/products/manufacturers/:manufacturer_id'             => 'manufacturers#delete'

  ## Options' routes
  get     '/products/options'                                    => 'options#index'
  post    '/products/options'                                    => 'options#new'
  get     '/products/options/:options_group_id'                  => 'options#show'
  put     '/products/options/:options_group_id'                  => 'options#edit'
  delete  '/products/options/:options_group_id'                  => 'options#delete'

  ## Products' routes
  get     '/products/items'                                      => 'products#index'
  post    '/products/items'                                      => 'products#new'
  get     '/products/items/:product_id'                          => 'products#show'
  put     '/products/items/:product_id'                          => 'products#edit'
  delete  '/products/items/:product_id'                          => 'products#delete'

  ## Reviews
  get     '/products/items/:product_id/reviews'                  => 'reviews#index'
  get     '/reviews'                                             => 'reviews#index'
  get     '/reviews/:review_id'                                  => 'reviews#show'
  put     '/reviews/:review_id'                                  => 'reviews#edit'
  delete  '/reviews/:review_id'                                  => 'reviews#delete'

  ## producs' Variants
  get     '/products/items/:product_id/variants'                 => 'variants#index'
  post    '/products/items/:product_id/variants'                 => 'variants#new'
  get     '/products/items/:product_id/variants/:variant_id'     => 'variants#show'
  put     '/products/items/:product_id/variants/:variant_id'     => 'variants#edit'
  delete  '/products/items/:product_id/variants/:variant_id'     => 'variants#delete'

  ## Orders' Routes
  get     '/accounts/:customer_id/orders'                        => 'orders#index'
  get     '/orders'                                              => 'orders#index'
  post    '/orders'                                              => 'orders#new'
  get     '/orders/:order_id'                                    => 'orders#show'
  put     '/orders/:order_id'                                    => 'orders#edit'
  delete  '/orders/:order_id'                                    => 'orders#delete'


  ## Shipments
  get    '/orders/:order_id/shipments'                           => 'shipments#index'
  get    '/shipments'                                            => 'shipments#index'
  post   '/shipments'                                            => 'shipments#new'
  get    '/shipments/:shipment_id'                               => 'shipments#show'
  put    '/shipments/:shipment_id'                               => 'shipments#edit'
  delete '/shipments/:shipment_id'                               => 'shipments#delete'

  ## Logs
  get     '/logs/'                                               => 'logs#index'

end












